| ggi | R Documentation |
Make a graph interactive
ggi(
plot = ggplot2::last_plot(),
width = NULL,
height = NULL,
keep_ratio = TRUE,
savewidget = FALSE,
dir = NULL,
name = "Plot",
replace = FALSE,
open = rlang::is_interactive(),
...,
iframe,
pixel_width
)
plot |
The graph, made with |
width |
The width in centimeters. Default to printing device's size. |
height |
The height in centimeters. Default to printing device's size. |
keep_ratio |
By default, the height is forced based of the relative
size of the MCA's axes. Set to |
savewidget |
Should the html widget be saved on disk ? The file is standalone:
one single |
dir |
If saved as file, the directory in which to save the html widget.
Default to temporary directory. Set global option |
name |
The name of the file to save. |
replace |
Replace file ? By default, number added to find a new name. |
open |
Should the resulting file be opened at once ? |
... |
Additional arguments to pass to |
iframe, pixel_width |
Deprecated and ignored: the widget sizes itself. |
An html plot, of class ggfacto_widget. In a knitr document,
setting option "ggfacto.widget_dir" writes it to its own file and embeds an
<iframe> instead of the widget itself: see ggfacto_widget.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.