| ggmca_3d | R Documentation |
Interactive 3D Plot for Multiple Correspondence Analyses (plotly::)
ggmca_3d(
res.mca,
data,
clust,
axes = 1:3,
base_zoom = 1,
remove_buttons = FALSE,
cone_size = 0.15,
view = "All",
camera_view,
aspectratio_from_eig = FALSE,
title,
ind_name.size = 10,
max_point_size = 30,
...,
dat,
cah
)
res.mca |
An object created with |
data |
The data frame the analysis was made on, in which to find the clusters. |
clust |
The variable of 'data' holding the clusters, typically made with
|
axes |
The axes to print, as a numeric vector of length 3. |
base_zoom |
The base level of zoom. |
remove_buttons |
Set to TRUE to remove buttons to change view. |
cone_size |
The size of the conic arrow at the end of each axe. |
view |
The starting point of view (in 3D) :
|
camera_view |
Possibility to add a (replace 'view') |
aspectratio_from_eig |
Set to 'TRUE' to modify axes length based on eigenvalues. |
title |
The title of the graph. |
ind_name.size |
The size of the names of individuals. |
max_point_size |
The size of the biggest point. |
... |
Additional arguments to pass to |
dat |
Deprecated former name of 'data'. Still accepted, with a warning; use 'data' instead. |
cah |
Deprecated former name of 'clust'. |
A plotly html interactive 3d (or 2d) graph.
data(tea, package = "FactoMineR")
res.mca <- multiple_correspondence_analysis(tea, 1:18)
ggmca_3d(res.mca)
# 3D graph with colored clusters
tea <- tea |>
dplyr::mutate(clust = hierarchical_clust(res.mca, ncp = 3, nb_clust = 6))
ggmca_3d(res.mca, tea, clust = clust)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.