| is_in_analysis | R Documentation |
'TRUE' for each row of the data frame the analysis was made on, 'FALSE' for the others: the rows filtered out (with the pipe or with 'filter'), those with a weight of 0, and the supplementary individuals of a principal component analysis. Use it to describe the analysed population:
'data |> dplyr::filter(is_in_analysis(res)) |> tabxplor::tab(SEXE, AGE)'
is_in_analysis(res)
res |
An analysis made with |
A logical vector, one value per row: inside dplyr::filter() or
dplyr::mutate(), of the data frame being read; outside, of the data frame the analysis
started from.
data(tea, package = "FactoMineR")
res.mca <- multiple_correspondence_analysis(tea, 1:18, filter = age < 30)
tea |>
dplyr::filter(is_in_analysis(res.mca)) |>
tabxplor::tab(sex, SPC)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.